/*****************************************************************************

  SineFunctions

  Displays two Sine Functions with their envelopes in two windows.
  Note, that the step size is chosen explicitly small to let the user
  interact with funplot while simulation is running. Use 'Break' in the
  'Extras' menu to abort the simulation loop or just simply quit.

  $Name: Funplot_v10 $
  $Revision: 1.1 $
  $Date: 2006/03/02 20:09:05 $

  Copyright (C) 1998-2006 Domenico Reggio, Software-Engineering.

*****************************************************************************/

#include "Funplot.h"
#include <math.h>


int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
                   LPSTR lpszCmdLine, int nCmdShow)
{
  // Register the Funplot window class
  Funplot::ClassRegister(hInstance, hPrevInstance, nCmdShow);

  // Program variables
  double x, y, ye;
  short  userBreak;

  // Instantiation of the first Funplot window
  Funplot Sine1("Sine Function 1");
  Sine1.SetLables("x","f(x)","f(x) = exp(x) * sin(10*x)");
  Sine1.SetRange(-1,11,-1.1,1.1);
  Sine1.SetNumGraphs(3);
  Sine1.SetGraphLable("Oscillating Function",1);
  Sine1.SetGraphLable("Upper Envelope",2);
  Sine1.SetGraphLable("Lower Envelope",3);
  Sine1.ShowGraphPoints(HIDE);
  Sine1.SetGraphMarkerType(SQUARE,1);
  Sine1.SetGraphMarkerType(TRIANGLE,2);
  Sine1.SetGraphMarkerType(CIRCLE,3);
  Sine1.ShowGraphMarker(SHOW);
  Sine1.SetGraphMarkerDrawRate(500);
  Sine1.ShowLegend(SHOW_UPRIGHT);
  Sine1.SetWindowPos(1,1);
  Sine1.SetWindowSize(900,400);
  Sine1.Rise();

  // Instantiation of the second Funplot window
  Funplot Sine2("Sine Function 2");
  Sine2.SetLables("x","f(x)","f(x) = x * sin(10/x)");
  Sine2.SetRange(-1,11,-11,11);
  Sine2.SetNumGraphs(3);
  Sine2.SetGraphColorNum(3, 1);
  Sine2.SetGraphColorNum(4, 2);
  Sine2.SetGraphColorNum(4, 3);
  Sine2.SetGraphLable("Oscillating Function",1);
  Sine2.SetGraphLable("Upper Envelope",2);
  Sine2.SetGraphLable("Lower Envelope",3);
  Sine2.ShowGraphPoints(SHOW);
  Sine2.SetGraphPointsDrawRate(500);
  Sine2.ShowLegend(SHOW_DOWNLEFT);
  Sine2.SetColorScheme(DARK);
  Sine2.SetWindowPos(200,300);
  Sine2.SetWindowSize(800,500);
  Sine2.Rise();

  for (x=0.0001; x<10; x+=0.0005)
  {
    // Function value of function 1 and envelopes
    y=  exp(-x)*sin(10*x);
    ye= exp(-x);

    // Plot data pair of function 1 and envelopes in window 1
    Sine1.LineTo(x, y,  1);
    Sine1.LineTo(x, ye, 2);
    Sine1.LineTo(x,-ye, 3);

    // Function value of function 2 and envelopes
    y=  x*sin(10*x);
    ye= x;

    // Plot data pair of function 2 and envelopes in window 2
    Sine2.LineTo(x, y,  1);
    Sine2.LineTo(x, ye, 2);
    Sine2.LineTo(x,-ye, 3);

    // Allow user interaction ... but continue
    Funplot::MessageCheck();

    // ... and leave in case of stop or break
    userBreak= Funplot::CheckUserBreak();
    if (userBreak==QUIT || userBreak==BREAK) break;
  }

  // If the user does not want to quit enter the 'endless' message loop
  if (userBreak!=QUIT) Funplot::MessageLoop();

  return 0;
}
